==> mysql-shell_8.0.36+dfsg.orig.tar.xz: mysql-shell-8.0.36-src/unittest/scripts/auto/py_shell/scripts/util_help_norecord.py <==
#@ util help
util.help()

#@ util help, \? [USE:util help]
\? util

#@ util check_for_server_upgrade help
util.help('check_for_server_upgrade')

#@ util check_for_server_upgrade help, \? [USE:util check_for_server_upgrade help]
\? check_for_server_upgrade

# WL13807-TSFR_1_1
#@ util dump_instance help
util.help('dump_instance');

#@ util dump_instance help, \? [USE:util dump_instance help]
\? dump_instance

# WL13807-TSFR_2_1
#@ util dump_schemas help
util.help('dump_schemas');

#@ util dump_schemas help, \? [USE:util dump_schemas help]
\? dump_schemas

# WL13804-TSFR_6_1
#@ util dump_tables help
util.help('dump_tables');

#@ util dump_tables help, \? [USE:util dump_tables help]
\? dump_tables

# WL13804-TSFR_1_4
#@ util export_table help
util.help('export_table');

#@ util export_table help, \? [USE:util export_table help]
\? export_table

#@ util import_json help
util.help('import_json')

#@ util import_json help, \? [USE:util import_json help]
\? import_json

#@ util import_table help
util.help('import_table')

#@ util import_table help, \? [USE:util import_table help]
\? import_table

#@ util load_dump help
util.help('load_dump')

#@ util load_dump help, \? [USE:util load_dump help]
\? load_dump

#@ util debug collect_diagnostics (full path)
\? util.debug.collect_diagnostics

#@ util debug collect_diagnostics with util.debug.help (partial path)
util.debug.help("collect_diagnostics")

#@ util debug collect_high_load_diagnostics
\? collect_high_load_diagnostics

#@ util debug collect_slow_query_diagnostics
\? collect_slow_query_diagnostics

==> mysql-shell_8.4.6+dfsg.orig.tar.xz: mysql-shell-8.4.6-src/unittest/scripts/auto/py_shell/scripts/util_help_norecord.py <==
#@ util help
util.help()

#@ util help, \? [USE:util help]
\? util

#@ util check_for_server_upgrade help
util.help('check_for_server_upgrade')

#@ util check_for_server_upgrade help, \? [USE:util check_for_server_upgrade help]
\? check_for_server_upgrade

#@ util copy_instance help
# WL15298_TSFR_1_1
# WL15298_TSFR_4_4_1
# WL15298_TSFR_5_1_1
util.help('copy_instance')

#@ util copy_instance help, \? [USE:util copy_instance help]
# WL15298_TSFR_1_1
# WL15298_TSFR_4_4_1
# WL15298_TSFR_5_1_1
\? copy_instance

#@ util copy_schemas help
# WL15298_TSFR_2_1
# WL15298_TSFR_4_4_1
# WL15298_TSFR_5_1_1
util.help('copy_schemas')

#@ util copy_schemas help, \? [USE:util copy_schemas help]
# WL15298_TSFR_2_1
# WL15298_TSFR_4_4_1
# WL15298_TSFR_5_1_1
\? copy_schemas

#@ util copy_tables help
# WL15298_TSFR_4_4_1
util.help('copy_tables')

#@ util copy_tables help, \? [USE:util copy_tables help]
# WL15298_TSFR_4_4_1
\? copy_tables

# WL13807-TSFR_1_1
#@ util dump_instance help
util.help('dump_instance')

#@ util dump_instance help, \? [USE:util dump_instance help]
\? dump_instance

# WL13807-TSFR_2_1
#@ util dump_schemas help
util.help('dump_schemas')

#@ util dump_schemas help, \? [USE:util dump_schemas help]
\? dump_schemas

# WL13804-TSFR_6_1
#@ util dump_tables help
util.help('dump_tables')

#@ util dump_tables help, \? [USE:util dump_tables help]
\? dump_tables

# WL13804-TSFR_1_4
#@ util export_table help
util.help('export_table')

#@ util export_table help, \? [USE:util export_table help]
\? export_table

#@ util import_json help
util.help('import_json')

#@ util import_json help, \? [USE:util import_json help]
\? import_json

#@ util import_table help
util.help('import_table')

#@ util import_table help, \? [USE:util import_table help]
\? import_table

#@ util load_dump help
util.help('load_dump')

#@ util load_dump help, \? [USE:util load_dump help]
\? load_dump

#@ util debug collect_diagnostics (full path)
\? util.debug.collect_diagnostics

#@ util debug collect_diagnostics with util.debug.help (partial path)
util.debug.help("collect_diagnostics")

#@ util debug collect_high_load_diagnostics
\? collect_high_load_diagnostics

#@ util debug collect_slow_query_diagnostics
\? collect_slow_query_diagnostics
